# bababooey.py

The most over-complicated module for the stupidest needs

## How to use!

`import bababooey` first, we must import bababooey.

---

`bababooey.bababooey()` returns what my complex bababooey algorithm returns.

`bababooey.bababooey2()` returns the boring, bababooey with no computations.

`bababooey.bababooey` returns the string bababooey.